@@ -1,8 +1,6 @@
 #ifndef COMMON_H
 #define COMMON_H
 
-#include <config.h>
-
 #define INTERNAL_ERROR cerr << "Internal error: " __FILE__ ":" << __LINE__ << "(Version =" VERSION ")" << endl
 
 class RootPortal;
@@ -15,6 +13,7 @@ extern int verbose;
 std::string getBaseDir();
 std::string getHomeDir();
 
+#define CONFIG_DIR ".root-portal"
 
 #ifdef DEBUG
 extern bool debug;
