@@ -2,13 +2,9 @@
 
 #include "common.h"
 
-#ifdef WITH_GNOME
 #include <gnome-xml/parser.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
-#else
-#include <gtk/gtk.h>
-#endif
 
 #include <gdk/gdkprivate.h>
 #include <unistd.h>
@@ -41,12 +37,8 @@ using namespace std;
 #include "module_registry.h"
 #include "utils.h"
 #include "modules/builtin_plugin_loader.h"
-
-#ifdef ENABLE_CONFIGURATOR
 #include "config/configuration.h"
-#endif
 
-#define CONFIG_DIR ".root-portal"
 #define DEFAULT_CONFIG CONFIG_DIR "/config.rdf"
 #define USER_PLUGIN_DIR CONFIG_DIR "/plugins"
 #define SYSTEM_CONFIG "/etc/root-portal.rdf"
@@ -185,6 +177,8 @@ string RootPortal::getPluginDir()
 }
 
 RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
+    : configurator(NULL),
+      remote_configure_request(false)
 {
         string homeDir = getHomeDir();
 
@@ -193,9 +187,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         /* configuration variables */
         int help = -1, enableVerbose = -1, version = -1;
         int set_slave_mode = -1;
-#ifdef ENABLE_CONFIGURATOR
         int ldconfigurator = -1, dontLdConfigurator = -1;
-#endif
         char *display_ = NULL;
         char *configuration_ = NULL;
         char *output_command_file_name = NULL;
@@ -212,8 +204,6 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 }
         }
 
-        bool no_popt = false;
-#ifdef WITH_GNOME
         /* this tells popt how to do magic on our variables */
         static const struct poptOption options[] = {
                 { "version", 'v', POPT_ARG_NONE, &version, 0,
@@ -241,14 +231,8 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
 #endif          
                 { NULL, '\0', 0, NULL, 0}
         };
-#else // WITH_GNOME
-        no_popt = true;
-#endif // WITH_GNOME
         
-        if (!with_x)
-                no_popt = true;
-
-        if (no_popt) {
+        if (!with_x) {
                 for (int i = 1; i < argc; i++) {
                         if (!strcmp(argv[i], "--help") || !strcmp(argv[i], "-h")) {
                                 cout << "-h  --help         display this help message\n"
@@ -275,11 +259,10 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         
         string display;
         if (with_x) {
-#ifdef WITH_GNOME
-                gnome_init_with_popt_table(PACKAGE, VERSION, argc, argv, options, 0, NULL);
-#else
-                gtk_init(&argc, &argv);
-#endif
+                gnome_program_init(PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+                                   argc, argv,
+                                   GNOME_PARAM_POPT_TABLE, options,
+                                   GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
                 if (display_ != NULL) {
                         display = display_;
@@ -358,7 +341,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 writeConfig = configuration;
 	}
 
-#ifdef WITH_GNOME
+#ifdef TO_PORT
         if (with_x) {
                 if (fcntl(ConnectionNumber(gdk_display), F_SETFD, FD_CLOEXEC) < 0) {
                         cerr << "Cannot detach fork." << endl;
@@ -366,7 +349,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 }
         }
 #endif
-	
+        
         if (verbose)
                 cout << "RP-" VERSION " using " << configuration << endl;
 
@@ -381,7 +364,6 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
 	
         ModuleTree::instance()->init();
         
-#ifdef WITH_XML
         if (!slave_mode) {
                 if (verbose)
                         cout << "reading configuration from \"" << configuration << "\"\n";
@@ -390,38 +372,7 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
         if (output_command_file.is_open()) {
                 output_command_file.close();
         }
-#else
-        if (!slave_mode) {
-                FILE *cmd_input;
-                string cmd_input_filename = homeDir + "/" CONFIG_DIR "/command.input";
-                cmd_input = fopen(cmd_input_filename.c_str(), "rb");
-                if (cmd_input != NULL) {
-                        if (verbose)
-                                cout << "reading command input from \""
-                                     << cmd_input_filename << "\"\n";
-                        string text;
-                        while (true) {
-                                int tmp = fgetc(cmd_input);
-                                if (tmp == EOF)
-                                        break;
-                                if (tmp <= 0 || tmp == 10 || tmp == 13 || tmp > 255 ) {
-                                        try {
-                                                cout << ModuleTree::instance()->issue_string_command(text) << endl;
-                                        } catch (ModuleError ex) {
-                                                cout << "!!ERROR!!" << ex.description << endl;
-                                        }
-                                        text = "";
-                                } else {
-                                        text += char(tmp);
-                                }
-                        }
-                } else {
-                        cerr << "Error opening \"" << cmd_input_filename << "\"\n";
-                }
-        }
-#endif
 
-#ifdef ENABLE_CONFIGURATOR
         if (with_x) {
                 configurator = new Configuration();
                 bool tmp = load_configurator_default;
@@ -432,7 +383,6 @@ RootPortal::RootPortal(int argc, char* argv[]) throw (StartupCancelled)
                 if (tmp)
                         configure();
         }
-#endif
 }
 
 RootPortal::~RootPortal()
@@ -444,15 +394,17 @@ RootPortal::~RootPortal()
 void RootPortal::service()
 {
         ModuleTree::instance()->service();
+        if (remote_configure_request && configurator != NULL) {
+                remote_configure_request = false;
+                configurator->displayConfigurator();
+        }
         //	usleep(50); // was 1000, change back before you release
 }
 
 void RootPortal::saveConfig()
 {
-#ifdef WITH_XML
         if (!slave_mode)
                 TreeSaverXml::instance()->save_to_file(writeConfig);
-#endif
 }
 
 void RootPortal::preShutdown()
@@ -477,6 +429,11 @@ void sigHandler(int sigNum)
                 case SIGSEGV:
                         cerr << "Root-Portal Segmentation Violation Detected.\n";
                 
+#ifdef CRASH_DEBUG
+                        char buffer[50];
+                        snprintf(buffer, sizeof(buffer), "program-crash %d", getpid());
+                        system(buffer);
+#else
 #ifdef HAVE_BACKTRACE
                         // borrowed from licq (http://www.licq.org/)
                         cerr << "Backtrace:\n";
@@ -488,7 +445,7 @@ void sigHandler(int sigNum)
                                         cerr << res[i] << endl;
                         }
 #endif
-
+#endif
                         abort();
                 default:
                         time_to_shutdown = true;
@@ -561,6 +518,7 @@ int main(int argc, char* argv[])
                 } else {
                         while (!time_to_shutdown) {
                                 roundnroundnroundwego(NULL);
+                                usleep(1000);
                         }
                 }
 
