@@ -2,11 +2,7 @@
 #define ROOTPORTAL_H
 
 #include "common.h"
-
-#ifdef ENABLE_CONFIGURATOR
 #include "config/configuration.h"
-#endif
-
 #include "datasetmap.h"
 #include "moduleinfo.h"
 #include "module_tree.h"
@@ -34,12 +30,8 @@ public:
         void load_settings();
         void save_settings();
         void configure() {
-#ifdef ENABLE_CONFIGURATOR
-                configurator->displayConfigurator();
-#else
-                cerr << "Configurator support not enabled during build\n";
-#endif
-        }        
+                remote_configure_request = true;
+        }
 
         void set_load_configurator_default(bool def) {
                 load_configurator_default = def;
@@ -54,14 +46,14 @@ private:
         string getPluginDir();
         bool fileExists(const string& name);
         void displayWelcomeMessage();
-#ifdef ENABLE_CONFIGURATOR
         Configuration* configurator;
-#endif
 
         int getLock(const string& displayName);
         void releaseLock();
 
         string writeConfig; // where to write back the configuration
+
+        bool remote_configure_request;
 };
 
 extern RootPortal* rootPortal;
